==> dolt-0.34.9.tar.gz: dolt-0.34.9/docs/roadmap.md <==
# Dolt feature roadmap

Full details on [supported SQL
features](https://docs.dolthub.com/interfaces/sql/sql-support) are
available on the docs site.

This is a selection of unimplemented features we're working on. Don't see what you need on here? [Let us
know!](https://github.com/dolthub/dolt/issues) Paying customers get
their feature requests implemented first.

| Feature                                                  | ETA      |
| -------                                                  | ---      |
| Hosted Dolt                                              | Jan 2022 |
| Join for update                                          | Oct 2021 |
| Backup and replication                                   | Nov 2021 |
| Commit graph performance                                 | Nov 2021 |
| Collation and charset support                            | Nov 2021 |
| Persistent SQL configuration                             | Dec 2021 |
| Multiple DBs in one repo                                 | Dec 2021 |
| Tx isolation levels                                      | Dec 2021 |
| 99.9% SQL correctness                                    | Q1 2022  |
| Better `dolt_diff` table experience                      | Q1 2022  |
| Hash join strategy                                       | Q1 2022  |
| Storage performance                                      | Q1 2022  |
| SQL GUI support tests                                    | Q1 2022  |
| Lock / unlock tables                                     | Q1 2022  |
| Users / grants                                           | Q2 2022  |
| `JSON_TABLE()`                                           | Q2 2022  |
| Pipeline query processing                                | Q2 2022  |
| Table / index statistics                                 | Q2 2022  |
| Universal SQL path for CLI                               | Q2 2022  |
| Row-level locking (select for update)                    | Q2 2022  |
| Virtual columns and json indexing                        | Q2 2022  |
| Embedded dolt                                            | Q3 2022  |
| Signed commits                                           | Q3 2022  |
| More window functions                                    | Unsched  |
| Cross-database joins with indexes                        | Unsched  |
| `ROWS PRECEDING` and `ROWS FOLLOWING` window definitions | Unsched  |
| More function coverage                                   | Unsched  |
| Geometry types and functions                             | Unsched  |

==> dolt-0.37.7.tar.gz: dolt-0.37.7/docs/roadmap.md <==
# Dolt feature roadmap

Full details on [supported SQL
features](https://docs.dolthub.com/reference/sql/support) are
available on the docs site.

This is a selection of unimplemented features we're working on. Don't see what you need on here? [Let us
know!](https://github.com/dolthub/dolt/issues) Paying customers get
their feature requests implemented first.

| Feature                                                  | ETA      |
| -------------------------------------------------------- | -------- |
| Hosted Dolt                                              | Jan 2022 |
| Join for update                                          | Oct 2021 |
| Backup and replication                                   | Nov 2021 |
| Commit graph performance                                 | Nov 2021 |
| Collation and charset support                            | Nov 2021 |
| Persistent SQL configuration                             | Dec 2021 |
| Multiple DBs in one repo                                 | Dec 2021 |
| Tx isolation levels                                      | Dec 2021 |
| 99.9% SQL correctness                                    | Q1 2022  |
| Better `dolt_diff` table experience                      | Q1 2022  |
| Hash join strategy                                       | Q1 2022  |
| Storage performance                                      | Q1 2022  |
| SQL GUI support tests                                    | Q1 2022  |
| Lock / unlock tables                                     | Q1 2022  |
| Users / grants                                           | Q2 2022  |
| `JSON_TABLE()`                                           | Q2 2022  |
| Pipeline query processing                                | Q2 2022  |
| Table / index statistics                                 | Q2 2022  |
| Universal SQL path for CLI                               | Q2 2022  |
| Row-level locking (select for update)                    | Q2 2022  |
| Virtual columns and json indexing                        | Q2 2022  |
| Embedded dolt                                            | Q3 2022  |
| Signed commits                                           | Q3 2022  |
| More window functions                                    | Unsched  |
| Cross-database joins with indexes                        | Unsched  |
| `ROWS PRECEDING` and `ROWS FOLLOWING` window definitions | Unsched  |
| More function coverage                                   | Unsched  |
| Geometry types and functions                             | Unsched  |
